pub struct UpdateUserRequest {Show 17 fields
pub email: Option<String>,
pub email_verified: Option<bool>,
pub verify_email: Option<bool>,
pub phone_number: Option<String>,
pub phone_verified: Option<bool>,
pub name: Option<String>,
pub given_name: Option<String>,
pub family_name: Option<String>,
pub nickname: Option<String>,
pub picture: Option<String>,
pub username: Option<String>,
pub password: Option<String>,
pub verify_password: Option<bool>,
pub blocked: Option<bool>,
pub connection: Option<String>,
pub user_metadata: Option<Value>,
pub app_metadata: Option<Value>,
}Expand description
Fields accepted by Auth0 PATCH /api/v2/users/{id}. All fields are optional — only non-None fields are serialized.
Fields
email: Option<String>email_verified: Option<bool>verify_email: Option<bool>phone_number: Option<String>phone_verified: Option<bool>name: Option<String>given_name: Option<String>family_name: Option<String>nickname: Option<String>picture: Option<String>username: Option<String>password: Option<String>verify_password: Option<bool>blocked: Option<bool>connection: Option<String>user_metadata: Option<Value>app_metadata: Option<Value>Implementations
Sourceimpl UpdateUserRequest
impl UpdateUserRequest
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new empty UpdateUserRequest with all fields set to None.
After construction, set the fields you want to update directly on the struct.
Only fields set to Some(...) are sent to Auth0 — the rest are omitted.
Fields
| Field | Type | Description |
|---|---|---|
email | Option<String> | New email address for the user |
email_verified | Option<bool> | Whether the email has been verified |
verify_email | Option<bool> | If true, sends a verification email after update |
phone_number | Option<String> | Phone number in E.164 format (e.g. +15551234567) |
phone_verified | Option<bool> | Whether the phone number has been verified |
name | Option<String> | Full display name |
given_name | Option<String> | First name |
family_name | Option<String> | Last name |
nickname | Option<String> | Preferred short name |
picture | Option<String> | URL of the user’s profile picture |
username | Option<String> | Username (only for connections that support it) |
password | Option<String> | New password (only for database connections) |
verify_password | Option<bool> | If true, sends a password-change confirmation email |
blocked | Option<bool> | If true, the user is blocked from logging in |
connection | Option<String> | Connection name the update applies to |
user_metadata | Option<Value> | Arbitrary JSON object editable by the user |
app_metadata | Option<Value> | Arbitrary JSON object editable only by the application |
Example
use auth0_integration::models::UpdateUserRequest;
let req = UpdateUserRequest::new();
// req.name = Some("Jane Doe".to_string());
// req.blocked = Some(false);Trait Implementations
Sourceimpl Default for UpdateUserRequest
impl Default for UpdateUserRequest
Sourcefn default() -> UpdateUserRequest
fn default() -> UpdateUserRequest
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for UpdateUserRequest
impl<'de> Deserialize<'de> for UpdateUserRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more